diff --git a/STARTERKIT/STARTERKIT.info.txt b/STARTERKIT/STARTERKIT.info.txt
index 57ddd35..acde1a7 100644
--- a/STARTERKIT/STARTERKIT.info.txt
+++ b/STARTERKIT/STARTERKIT.info.txt
@@ -118,7 +118,8 @@ settings[zen_breadcrumb_separator] = ' › '
 settings[zen_breadcrumb_home]      = 1
 settings[zen_breadcrumb_trailing]  = 1
 settings[zen_breadcrumb_title]     = 0
-settings[zen_jump_link_target]     = main-menu
+settings[zen_skip_link_href]       = main-menu
+settings[zen_skip_link_text]       = Skip to navigation
 settings[zen_rebuild_registry]     = 1
 settings[zen_wireframes]           = 0
 
diff --git a/template.php b/template.php
index 6b51ab8..2fa078a 100644
--- a/template.php
+++ b/template.php
@@ -210,7 +210,8 @@ function zen_preprocess_html(&$variables, $hook) {
       $variables['classes_array'][] = 'page-panels';
       break;
   }
-  $variables['jump_link_target'] = theme_get_setting('zen_jump_link_target');
+  $variables['skip_link_href'] = theme_get_setting('zen_skip_link_href');
+  $variables['skip_link_text'] = t(theme_get_setting('zen_skip_link_text'));
 }
 
 /**
diff --git a/theme-settings.php b/theme-settings.php
index 98d0371..cbcf5e4 100644
--- a/theme-settings.php
+++ b/theme-settings.php
@@ -86,12 +86,18 @@ function zen_form_system_theme_settings_alter(&$form, $form_state) {
                         ),
     '#default_value' => theme_get_setting('zen_layout'),
   );
-  $form['themedev']['zen_jump_link_target'] = array(
+  $form['themedev']['zen_skip_link_href'] = array(
     '#type'          => 'textfield',
-    '#title'         => t('Anchor ID for “Jump to Navigation” link'),
-    '#default_value' => theme_get_setting('zen_jump_link_target'),
+    '#title'         => t('Anchor ID for the skip link'),
+    '#default_value' => theme_get_setting('zen_skip_link_href'),
     '#field_prefix'  => '#',
-    '#description'   => t('Specify the HTML ID of the main navigation menu; this will be used by the accessible-but-hidden “Jump to Navigation" link at the top of each page.'),
+    '#description'   => t('The HTML ID of the element that the accessible-but-hidden skip link at the top of each page should link to. (<a href="!link">About skip links</a>)', array('!link' => 'http://drupal.org/node/467976')),
+  );
+  $form['themedev']['zen_skip_link_text'] = array(
+    '#type'          => 'textfield',
+    '#title'         => t('Text for the skip link'),
+    '#default_value' => theme_get_setting('zen_skip_link_text'),
+    '#description'   => t('For example: <em>Skip to navigation</em>, <em>Skip to content</em>'),
   );
   $form['themedev']['zen_wireframes'] = array(
     '#type'          => 'checkbox',
diff --git a/zen.info b/zen.info
index 4aa45c6..c598a6e 100644
--- a/zen.info
+++ b/zen.info
@@ -23,6 +23,7 @@ settings[zen_breadcrumb_home]      = 1
 settings[zen_breadcrumb_trailing]  = 1
 settings[zen_breadcrumb_title]     = 0
 settings[zen_layout]               = zen-columns-liquid
-settings[zen_jump_link_target]     = main-menu
+settings[zen_skip_link_href]       = main-menu
+settings[zen_skip_link_text]       = Skip to navigation
 settings[zen_rebuild_registry]     = 0
 settings[zen_wireframes]           = 0


diff --git a/templates/html.tpl.php b/templates/html.tpl.php
index 2f04b89..38fba86 100644
--- a/templates/html.tpl.php
+++ b/templates/html.tpl.php
@@ -25,8 +25,9 @@
  * - $styles: Style tags necessary to import all CSS files for the page.
  * - $scripts: Script tags necessary to load the JavaScript files and settings
  *   for the page.
  * - $jump_link_target: The HTML ID of the element that the "Jump to Navigation"
  *   link should jump to. Defaults to "main-menu".
  * - $page_top: Initial markup from any modules that have altered the
  *   page. This variable should always be output first, before all other dynamic
  *   content.
@@ -71,7 +72,7 @@
 </head>
 <body class="<?php print $classes; ?>" <?php print $attributes;?>>
   <div id="skip-link">
-    <a href="#<?php print $jump_link_target; ?>" class="element-invisible element-focusable"><?php print t('Jump to Navigation'); ?></a>
+    <a href="#<?php print $skip_link_href; ?>" class="element-invisible element-focusable"><?php print $skip_link_text; ?></a>
   </div>
   <?php print $page_top; ?>
   <?php print $page; ?>
@@ -25,8 +25,9 @@
  * - $scripts: Script tags necessary to load the JavaScript files and settings
  *   for the page.
- * - $jump_link_target: The HTML ID of the element that the "Jump to Navigation"
- *   link should jump to. Defaults to "main-menu".
+ * - $skip_link_href: The HTML ID of the element that the skip link should link to.
+ *   Defaults to "main-menu".
+ * - $skip_link_text: Text for the skip link. Defaults to "Skip to navigation".
  * - $page_top: Initial markup from any modules that have altered the
  *   page. This variable should always be output first, before all other dynamic